export function getImg(el) {
    const imgEl = el instanceof HTMLImageElement
        ? el
        : (el.querySelector('img') ?? el.shadowRoot?.querySelector('img'));
    if (!imgEl) {
        throw new Error('No <img> found');
    }
    return imgEl;
}
export async function loaded(el, options = {}) {
    let resolve;
    let reject;
    const loaded = new Promise((res, rej) => {
        resolve = res;
        reject = rej;
    });
    const imgEl = getImg(el);
    if (imgEl.complete) {
        resolve();
    }
    else {
        imgEl.addEventListener('load', () => {
            setTimeout(resolve, 0);
        }, { once: true });
        if (options.rejectOnError) {
            imgEl.addEventListener('error', (e) => {
                console.error(e.message);
                reject(e);
            }, { once: true });
        }
    }
    return loaded;
}
export async function trigger(el) {
    const fakeEvent = new Event('load');
    getImg(el).dispatchEvent(fakeEvent);
}
//# sourceMappingURL=image-helper.js.map